@@ -76,7 +76,7 @@ typedef void (*qmi_destroy_func_t)(void *user_data);
 struct qmi_device;
 
 typedef void (*qmi_debug_func_t)(const char *str, void *user_data);
-
+typedef void (*qmi_sync_func_t)(void *user_data);
 typedef void (*qmi_shutdown_func_t)(void *user_data);
 typedef void (*qmi_discover_func_t)(uint8_t count,
 			const struct qmi_version *list, void *user_data);
@@ -96,6 +96,10 @@ bool qmi_device_discover(struct qmi_device *device, qmi_discover_func_t func,
 bool qmi_device_shutdown(struct qmi_device *device, qmi_shutdown_func_t func,
 				void *user_data, qmi_destroy_func_t destroy);
 
+bool qmi_device_sync(struct qmi_device *device,
+		     qmi_sync_func_t func, void *user_data);
+bool qmi_device_is_sync_supported(struct qmi_device *device);
+
 enum qmi_device_expected_data_format qmi_device_get_expected_data_format(
 						struct qmi_device *device);
 bool qmi_device_set_expected_data_format(struct qmi_device *device,
@@ -140,6 +144,8 @@ bool qmi_result_get_uint64(struct qmi_result *result, uint8_t type,
 							uint64_t *value);
 void qmi_result_print_tlvs(struct qmi_result *result);
 
+int qmi_error_to_ofono_cme(int qmi_error);
+
 struct qmi_service;
 
 typedef void (*qmi_result_func_t)(struct qmi_result *result, void *user_data);
