@@ -36,6 +36,7 @@
 static int xmm7modem_init(void)
 {
 	xmm_radio_settings_init();
+	xmm_ims_init();
 
 	return 0;
 }
@@ -43,6 +44,7 @@ static int xmm7modem_init(void)
 static void xmm7modem_exit(void)
 {
 	xmm_radio_settings_exit();
+	xmm_ims_exit();
 }
 
 OFONO_PLUGIN_DEFINE(xmm7modem, "Intel xmm7xxx series modem driver",
